searchData={"items":[{"type":"module","title":"Astrex","doc":"","ref":"Astrex.html"},{"type":"module","title":"Introduction - Astrex","doc":"The Astrex library provides functions that perform astronomical calculations of various kinds.\n\n  - az2eq          converts from horizontal to equatorial coordinates\n  - eq2az          converts from equatorial to horizontal coordinates\n  - where_is       returns the equatorial coordinates of the specified planet or the moon\n  - geomag         returns the magnetic declination for the current location\n\n  All these functions are location dependent (latitude and longitude) and generally are also time\n  dependent.\n\n  The library provides a genserver to host local coordinates, which is responsibility of the\n  application to start, supervise and initialize with the local coordinates.\n\n  All the functions from the main Astrex module will retrieve the local coordinates from the server\n  and use the system time. This is handy for usage by applications that are geographically specific\n  and work in real time, e.g. for telescope control.\n\n  However, all the functions can be accessed directly from the respective modules by specifying the\n  desired coordinate and timestamp.\n\n  Bonus\n  - sidereal_speeds, a function to calculate the altitude and azimuth sidereal speeds for a sky point at\n    any given altitude/azimuth (only available for current system time and current genserver location)\n    Two calculation methods are provided. Both return consistent results, with some small difference which\n    does not affect the telescope driving speeds, when used with typical gear ratios.","ref":"Astrex.html#module-introduction"},{"type":"module","title":"Conventions - Astrex","doc":"The following conventions apply throughout the whole library (unless otherwise indicated):\n  - Longitudes East of Greenwich is POSITIVE: 0° to 180°\n  - Longitudes West of Greenwich is NEGATIVE: 0° to -180°\n  - Azimuth North is 0°\n  - Azimuth East is 90°\n  - Azimuth South is 180°\n  - Azimuth West is 270°","ref":"Astrex.html#module-conventions"},{"type":"module","title":"Units - Astrex","doc":"Unless otherwise indicated. all data need to be expressed in degrees, not in deegrees:minutes:seconds nor in radians","ref":"Astrex.html#module-units"},{"type":"module","title":"References - Astrex","doc":"The source of the algorithms is indicated in the docs of each function.","ref":"Astrex.html#module-references"},{"type":"module","title":"VERSIONS - Astrex","doc":"1.3.1 Initial public release\n\n   1.4.0 the WMM.COF file is updated to 2025 epoc. Unfortunately the WMM does not publish a link to the latest WMM file, each subsequent epoc needs to be downloaded and updated manually when published. Each epoc file is valid for several years\n\n   1.4.0 Added locationing of bright stars with a database of 200 stars, all above magnitude 3.1\n\n   1.4.1 Prevented error due to Gimbal Lock in sidereal_speeds/1\n\n   1.4.1 Updated dependencies","ref":"Astrex.html#module-versions"},{"type":"function","title":"Astrex.az2eq/1","doc":"Converts from AltAzimth coordinates to Equatorial Celestial coordinates\n\n  Does not compensate for the refraction effect. If needed, the compensation can be\n  applied to the coords argument before calling this function.\n\n  See Astrex.Astro.Refraction module.","ref":"Astrex.html#az2eq/1"},{"type":"function","title":"Astrex.eq2az/1","doc":"Converts from Equatorial Celestial coordinates to AltAzimth coordinates\n\n  Does not compensate for the refraction effect. If needed, the compensation can be\n  applied to the results of this function.\n\n  See Astrex.Astro.Refraction module.","ref":"Astrex.html#eq2az/1"},{"type":"function","title":"Astrex.mag_declination/1","doc":"Calculates the magnetic deviation from true north, given the local site coordinates\n  (latitude, longitude) and optionally the height above see level. The height is expressed\n  in Km and defaults to zero.\n\n  Returns a tuple with the following values, in this order:\n    - magnetic declination\n    - magnetic inclination\n    - total magnetic field intensity\n    - epoch of the current datafile\n\n  The magnetic declination value shoud be added to a magnetic compass reading to get the real\n  orientation (true north) of the device.","ref":"Astrex.html#mag_declination/1"},{"type":"function","title":"Astrex.sidereal_speeds2/2","doc":"Alternative method to calculate the sidereal speed starting from equatorial coordinates\n  1) calculates the AltAz coordinates for current time\n  2) calculates the AltAz coordinates for current time + one second\n  3) calculates the difference, which are the speeds in degrees per second\n\n  The results are very close to the sidereal speeds calculated with the mathematical method.\n  The difference is not enough to impact on motors rotation Hz","ref":"Astrex.html#sidereal_speeds2/2"},{"type":"function","title":"Examples - Astrex.sidereal_speeds2/2","doc":"iex> Astrex.sidereal_speeds2(%{alt: 45, az: 10}, 1)\n    {4.5187822290415625e-4, 7.061364708533802e-4}","ref":"Astrex.html#sidereal_speeds2/2-examples"},{"type":"function","title":"Astrex.sidereal_speeds/1","doc":"Calculates the sidereal speed, in degrees per second, for any given point\n  from it's altitude and azimuth coordinates\n  Source:\n      \"A Mathematical Description of the Control System for the William Herschel\n      Telescope\" R.A.Laing, Royal Greenwich Observatory\" pages 2/3","ref":"Astrex.html#sidereal_speeds/1"},{"type":"function","title":"Examples - Astrex.sidereal_speeds/1","doc":"iex> Astrex.sidereal_speeds(%{alt: 45, az: 10})\n    {4.5061593459496844e-4, 7.042059181503614e-4}","ref":"Astrex.html#sidereal_speeds/1-examples"},{"type":"function","title":"Astrex.where_is/1","doc":"Returns the current equatorial coordinates of the Moon or planets (including Pluto).\n\n  The coordinates are returned in Degrees (declination) and Hours (right ascension)","ref":"Astrex.html#where_is/1"},{"type":"function","title":"Examples - Astrex.where_is/1","doc":"iex> Astrex.where_is(:saturn)\n    %{dec: -15.285237885762347, ra: 21.665144627176584}\n    iex> Astrex.where_is(:moon)\n    %{dec: 15.889732428707166, ra: 2.705974878446635}","ref":"Astrex.html#where_is/1-examples"},{"type":"module","title":"Astrex.Application","doc":"","ref":"Astrex.Application.html"},{"type":"module","title":"Astrex.Astro.Dates","doc":"This module provides high accuracy functions to calculate key date values\n  for further astronomical calculations.\n  - Greenwhich Mean Standard Time\n  - Local Sidereal Time\n  - Julian Day with decimal precision (if decimals not required, Timex.to_julian can be used instead)\n  - Julian Century\n\n  Algorithms and coefficients to calculate GMST and LST have been taken\n  form the following articles:\n    https://astronomy.stackexchange.com/questions/24859/local-sidereal-time\n    https://squarewidget.com/astronomical-calculations-sidereal-time/","ref":"Astrex.Astro.Dates.html"},{"type":"function","title":"Astrex.Astro.Dates.day_number/1","doc":"returns the number of the specified date from 31.12.2000\n\n  reference: calculations according to Jean Meeus \"Astronomical Algorithms\"\n             chapter 7 - Julian Day","ref":"Astrex.Astro.Dates.html#day_number/1"},{"type":"function","title":"Astrex.Astro.Dates.gmst/1","doc":"Greenwitch Mean Sidereal Time for a given day/time\n\n  site where to confirm the calculation for arbitrary location and current time\n  https://astro.subhashbose.com/siderealtime/?longitude=9.15","ref":"Astrex.Astro.Dates.html#gmst/1"},{"type":"function","title":"Astrex.Astro.Dates.julian_century/1","doc":"returns the julian centuries from 1.1.2000","ref":"Astrex.Astro.Dates.html#julian_century/1"},{"type":"function","title":"Astrex.Astro.Dates.julian_day/1","doc":"returns julian day for the given date/time.\n\n  reference: calculations according to Jean Meeus \"Astronomical Algorithms\"\n             chapter 7 - Julian Day\n\n  receives a NaiveDateTime struct\n  returns a float day.decimals\n\n  if decimals are not necessary this can be\n  easily replaced by the function:  Timex.to_julian/1","ref":"Astrex.Astro.Dates.html#julian_day/1"},{"type":"function","title":"Astrex.Astro.Dates.local_sidereal_time/2","doc":"Local Sidereal Time for a given day/time\n  receives longitude in DEGREES and date and time as NaiveDateTime struct\n  returns sidereal time expressed in HOURS\n\n  Conventions:\n  Longitude is negative east of Greenwich\n\n  The following example are time dependent and will return the shown results only in testing environment","ref":"Astrex.Astro.Dates.html#local_sidereal_time/2"},{"type":"function","title":"Examples - Astrex.Astro.Dates.local_sidereal_time/2","doc":"iex> Astrex.Astro.Dates.local_sidereal_time(9.15, Astrex.Common.ndt_now()) |> Astrex.Common.hours2hms\n    \"00:08:11\"","ref":"Astrex.Astro.Dates.html#local_sidereal_time/2-examples"},{"type":"module","title":"Astrex.Astro.GeoMag","doc":"Calculates the Earth Magnetic field basing on local coordinates and (optionally) altitude.\n  The calculations model is the WMM (World Magnetic Model).\n\n  More information available here:\n      https://www.ngdc.noaa.gov/geomag/WMM/\n\n  The datafile WMM.COF\n      https://www.ngdc.noaa.gov/geomag/WMM/data/WMM2020/WMM2020COF.zip\n  is valid until 2025 and will be replaced when the next one will be released\n\n  Calculations results have been compared to the results of this calculator's\n      https://www.ngdc.noaa.gov/geomag/calculators/magcalc.shtml#declination\n  and the prove accurate with an error margin of about 1/100° likely due to floating point roundings\n\n  This code has been directly ported from a python implementation available at\n      https://github.com/cmweiss/geomag/blob/master/geomag/geomag/geomag.py","ref":"Astrex.Astro.GeoMag.html"},{"type":"function","title":"Astrex.Astro.GeoMag.mag_declination/2","doc":"Requires latitude and longitude expressed in decimal degrees (not deg, min, sec)\n  - Latitude: between 0° and 90° -- southern latitudes are negative\n  - Longitude: between 0° and +/- 180° -- western longitudes are negative\n  - Altitude: in km above sea level - optional parameter, default is 0","ref":"Astrex.Astro.GeoMag.html#mag_declination/2"},{"type":"function","title":"Returns - Astrex.Astro.GeoMag.mag_declination/2","doc":"dec: magnetic declination\n    dip: magnetic inclination\n    ti: total intensity\n    epoch: Epoch of the current datafile","ref":"Astrex.Astro.GeoMag.html#mag_declination/2-returns"},{"type":"function","title":"Examples - Astrex.Astro.GeoMag.mag_declination/2","doc":"iex> Astrex.Astro.GeoMag.mag_declination(%{lat: 45.5, long: 9.15})\n    {3.3219734037666426, 61.709940202847136, 47715.72107126719, \"2020.0\"}","ref":"Astrex.Astro.GeoMag.html#mag_declination/2-examples"},{"type":"module","title":"Astrex.Astro.Moon","doc":"This module exports one function that computes the Moon coordinates\n  according to algoritm and QBasic source code from:\n\n  http://www.stargazing.net/kepler/moon.html  QBasic code.\n  http://stargazing.net/kepler/moon2.html\n\n  this is faster than Meeus algoritm and reasonably accurate (4 arcminutes 99% of the times 1 arcmin 50% of times)","ref":"Astrex.Astro.Moon.html"},{"type":"function","title":"Astrex.Astro.Moon.moon/1","doc":"receives a NaiveDateTime struct\nreturns the Moon's coordinates (RA/DEC) at the specified date/time","ref":"Astrex.Astro.Moon.html#moon/1"},{"type":"module","title":"Astrex.Astro.Refraction","doc":"Refraction can change significantly the apparent altitude of an object.\n  The change depends solely on the altitude and is maximun on the\n  horizon (objects may appear above the horizon when they are\n  actually still below) and zero at the zenith\n\n  This module exports functions to calculate the true altitude\n  given the apparent one, and to calculate the apparent altitude\n  if the true one is known - typically calculated starting from\n  equatorial coordinate system.\n\n  The algorithms are taken from Jean Meeus book: \"Astronomical Algorithms\"\n  Chapter 16 - Atmospheric Refraction","ref":"Astrex.Astro.Refraction.html"},{"type":"function","title":"Astrex.Astro.Refraction.apparent_alt/1","doc":"Receives a T.altazimuth map including the true altitude.\n  Returns a T.altazimuth map including the apparent altitude.\n\n  The true altitude is calculated from the equatorial coordinates of the object.\n  The apparent altitude corresponds to where the digital setting circles must aim\n  to center the object","ref":"Astrex.Astro.Refraction.html#apparent_alt/1"},{"type":"function","title":"Examples - Astrex.Astro.Refraction.apparent_alt/1","doc":"iex> Astrex.Astro.Refraction.apparent_alt(%{alt: 45, az: 180})\n    %{alt: 45.016878460981225, az: 180}","ref":"Astrex.Astro.Refraction.html#apparent_alt/1-examples"},{"type":"function","title":"Astrex.Astro.Refraction.true_alt/1","doc":"Receives a T.altazimuth map including the apparent altitude\n  Returns a T.altazimuth map including the true altitude\n\n  The apparent altitude corresponds to the digital setting circles readings\n  The true altitude allows to precisely calculate the equatorial coordinates\n  of the point the telescope is aiming at.","ref":"Astrex.Astro.Refraction.html#true_alt/1"},{"type":"function","title":"Examples - Astrex.Astro.Refraction.true_alt/1","doc":"iex> Astrex.Astro.Refraction.true_alt(%{alt: 45, az: 180})\n    %{alt: 44.98341920053572, az: 180}","ref":"Astrex.Astro.Refraction.html#true_alt/1-examples"},{"type":"module","title":"Astrex.Astro.SolarSystem","doc":"This module exports only one function to retrieve the current equatorial\n  coordinates of the 9 planets (including Pluto) and of the Moon (via the Astrex.Astro.Moon module)\n\n  The coordinates are returned in Degrees (declination) and Hours (right ascension)\n\n  Algoritm and original javascript source code from\n  https://cdpn.io/lulunac27/fullpage/NRoyxE  - planets","ref":"Astrex.Astro.SolarSystem.html"},{"type":"function","title":"Astrex.Astro.SolarSystem.where_is/2","doc":"Receives an atom (requested object) and a datetime\nreturns the coordinates (RA/DEC) of the requested object\n\nvalid atoms:\n  :mercury\n  :venus\n  :moon\n  :mars\n  :jupiter\n  :saturn\n  :uranus\n  :neptune\n  :pluto","ref":"Astrex.Astro.SolarSystem.html#where_is/2"},{"type":"module","title":"Astrex.Astro.Transforms","doc":"The module exports functions to convert from different coordinates systems\n    AltAzimuth to Equatorial\n    Equatorial to AltAzimuth\n    Ecliptic to Equatorial\n    Equatorial to Ecliptical\n\n  Unless otherwise stated the formulas are implemented according to the Jean Meeus book:\n  \"Astronomical Algorithms\"\n\n  Chapter 13 - Transformation of Coordinates\n\n  The following conventions apply:\n    Longitudes East of Greenwich is POSITIVE: 0° to 180°\n    Longitudes West of Greenwich is NEGATIVE: 0° to -180°\n    Azimuth North is 0°\n    Azimuth East is 90°\n    Azimuth South is 180°\n    Azimuth West is 270°\n\n  All data need to be expressed in radians, not in degrees or hours","ref":"Astrex.Astro.Transforms.html"},{"type":"function","title":"Astrex.Astro.Transforms.az2eq/3","doc":"Converts from AltAzimth coordinates to Equatorial Celestial coordinates\n          Follows the Azimuth convention of South @ 180° (performs the necessary\n          conversion to comply to Meeus algo which is South @ 0°)\n  Receives: map: Altitude, Azimuth in DEGREES\n            map: Latitude, Longitude in DEGREES\n            NaiveDateTime\n\n  Returns : map: Right Ascension, Declination in DEGREES\n\n  Note: does NOT take refraction into account","ref":"Astrex.Astro.Transforms.html#az2eq/3"},{"type":"function","title":"Astrex.Astro.Transforms.ecl2eq/2","doc":"Converts ecliptical latitude and logitude to equatorial AR / DEC at a given time\n\n  Opposite to eq2ecl, there are no reliable test numbers available\n  Therefore this function can only be tested via round trip together with eq2ecl","ref":"Astrex.Astro.Transforms.html#ecl2eq/2"},{"type":"function","title":"Examples - Astrex.Astro.Transforms.ecl2eq/2","doc":"iex> test = %{dec: 25.989, ra: 277.892}  # or whatever coordinates\n    iex> date = Astrex.Common.ndt_now()\n    iex> Astrex.Astro.Transforms.eq2ecl(test, date) |> Astrex.Astro.Transforms.ecl2eq(date)\n    %{dec: 25.989000000000008, ra: 277.89199999999994}\n\n    PASSES with float operations approximation","ref":"Astrex.Astro.Transforms.html#ecl2eq/2-examples"},{"type":"function","title":"Astrex.Astro.Transforms.eq2az/3","doc":"Converts from Equatorial Celestial coordinates to AltAzimth coordinates\n           according to Jean Meeus Algorithm\n           Follows the Azimuth convention of South @ 180° (performs the necessary\n           conversion to comply to Meeus algo which is South @ 0°)\n  Receives: map: Right Ascension and Declination in DEGREES\n            map: Latitude, Longitude in DEGREES\n            NaiveDateTime\n  Returns : map: Altitude and Azimuth in DEGREES\n\n  (see Meeus Astronomical Algorithms page 95 example 13.b)","ref":"Astrex.Astro.Transforms.html#eq2az/3"},{"type":"function","title":"Examples: - Astrex.Astro.Transforms.eq2az/3","doc":"iex> site = %{lat: 38.921, long: 77.065}\n    iex> obj  = %{ra: 347.316, dec: -6.719}\n    iex> date = ~N[1987-04-10 19:21:00]\n    iex> Astrex.Astro.Transforms.eq2az(obj, site, date)\n    %{alt: 15.122211840841763, az: 248.037813189937}\n\n    Note: the example from the book returns az: 68.037813189937 because the azimuth convention\n          is 0° South. We use 180° for south.","ref":"Astrex.Astro.Transforms.html#eq2az/3-examples"},{"type":"function","title":"Astrex.Astro.Transforms.eq2ecl/2","doc":"Converts equatorial AR / DEC to ecliptical latitude and logitude at a given time\n\n  Receives:\n  RA/DEC expressed in DEGREES\n  Returns:\n  Longitude/Latitude (ecliptical) expressed in DEGREES","ref":"Astrex.Astro.Transforms.html#eq2ecl/2"},{"type":"function","title":"Examples - Astrex.Astro.Transforms.eq2ecl/2","doc":"iex> date = ~N[1987-04-10 00:00:00]\n    iex> obj  = %{ra: 116.328942, dec: 28.026183}\n    iex> Astrex.Astro.Transforms.eq2ecl(obj, date)\n    %{lambda: 113.215630, beta: 6.68417}  # in degrees\n\n    PASSES with float operations approximation","ref":"Astrex.Astro.Transforms.html#eq2ecl/2-examples"},{"type":"module","title":"Astrex.Common","doc":"Common utilities to facilitate the astronomical calculations\n  - unit conversions: hours, degrees, angles\n  - normalizations within 360°, 2PI, 24 hours\n  - conversion from hour:minutes:seconds to hours and back\n  - conversion from degree:minutes:seconds to degrees and back","ref":"Astrex.Common.html"},{"type":"function","title":"Astrex.Common.deg2dms/1","doc":"formats an angle from degrees to a string \"dd:mm:ss\"","ref":"Astrex.Common.html#deg2dms/1"},{"type":"function","title":"Examples - Astrex.Common.deg2dms/1","doc":"iex> Astrex.Common.hours2hms(174.1234)\n    \"174:07:24\"","ref":"Astrex.Common.html#deg2dms/1-examples"},{"type":"function","title":"Astrex.Common.deg2hours/1","doc":"converts an angle expressed in degrees to an angle expressed in hours","ref":"Astrex.Common.html#deg2hours/1"},{"type":"function","title":"Astrex.Common.dms2deg/1","doc":"Converts a \"dd:mm:ss\" string to degrees\n  Receives the angle in d° m' s\" as a binary string\n  Returns the angle in DEGREES (float)","ref":"Astrex.Common.html#dms2deg/1"},{"type":"function","title":"Astrex.Common.hms2hours/1","doc":"Converts a \"hh:mm:ss\" string to hours\n  receives a binary string\n  returns HOURS in float format","ref":"Astrex.Common.html#hms2hours/1"},{"type":"function","title":"Examples - Astrex.Common.hms2hours/1","doc":"iex> Astrex.Common.hms2hours(\"12:33:31\")\n    12.558611111111112","ref":"Astrex.Common.html#hms2hours/1-examples"},{"type":"function","title":"Astrex.Common.hours2deg/1","doc":"converts an angle expressed in hours to an angle expressed in degrees","ref":"Astrex.Common.html#hours2deg/1"},{"type":"function","title":"Astrex.Common.hours2hms/1","doc":"formats an hour from hours to a string \"hh:mm:ss\"","ref":"Astrex.Common.html#hours2hms/1"},{"type":"function","title":"Examples - Astrex.Common.hours2hms/1","doc":"iex> Astrex.Common.hours2hms(12.5587)\n    \"12:33:31\"","ref":"Astrex.Common.html#hours2hms/1-examples"},{"type":"function","title":"Astrex.Common.hours2rad/1","doc":"converts an angle expressed in hours to an angle expressed in radians","ref":"Astrex.Common.html#hours2rad/1"},{"type":"function","title":"Astrex.Common.map2deg/1","doc":"Converts all values of a map from radians to degrees.","ref":"Astrex.Common.html#map2deg/1"},{"type":"function","title":"Astrex.Common.map2rad/1","doc":"Converts all values of a map from degrees to radians.","ref":"Astrex.Common.html#map2rad/1"},{"type":"function","title":"Astrex.Common.ndt_now/0","doc":"returns the current time:\n  - system time if production\n  - mock time is testing","ref":"Astrex.Common.html#ndt_now/0"},{"type":"function","title":"Astrex.Common.norm_2pi/1","doc":"Normalizes an angle into the range 0-2 pi\n  Receives the angle in RADIANS\n  Returns the normalized angle in RADIANS","ref":"Astrex.Common.html#norm_2pi/1"},{"type":"function","title":"Astrex.Common.norm_24h/1","doc":"Normalizes an hour angle into the range 0-24 hours\n  Receives the angle in HOURS\n  Returns the normalized angle in HOURS","ref":"Astrex.Common.html#norm_24h/1"},{"type":"function","title":"Astrex.Common.norm_360/1","doc":"Normalizes an angle into the range 0°-360°\n  Receives the angle in DEGREES\n  Returns the normalized angle in DEGREES","ref":"Astrex.Common.html#norm_360/1"},{"type":"function","title":"Astrex.Common.rad2hours/1","doc":"converts an angle expressed in radians to an angle expressed in hours","ref":"Astrex.Common.html#rad2hours/1"},{"type":"module","title":"Astrex.DeepSky","doc":"This module provides functions to query for DeepSky objects recorded in the NGC and IC catalogs\n\n  The catalog is taken from https://github.com/mattiaverga/OpenNGC (License CC-BY-4.0) and saved\n  locally in priv directory\n\n  Some columns have been dropped for space sake. The available columns are\n    0: Name             IC or NGC index\n    1: Type             G: Galaxy, Neb: Nebula, OCl: Open Cluster, GCl: Globular Cluster\n    2: RA               Right Ascension\n    3: Dec              Declination\n    4: Const            Constellation\n    5: B-Mag            Magnitude\n    6: M                Messier index, if existing\n\n  The following searches are provided\n  - by direct calatog and id# - will return one item, if found\n  - by specifying the maximum magnitude, object type, minimum altitude on the horizon\n    and if the search should be limited to Messier objects\n\n  the object types that can be specified, as atoms, are:\n  - galaxies:\n  - openclusters:\n  - globularclusters:\n  - nebulas: (all kinds)\n\n  Note: Coordinates of the objects are returned in (+/-)dd:mm:ss and hh:mm:ss (strings)\n        this is how they are stored in the catalog and are not converted in order\n        not to loose compatibility with new possible catalog releases.","ref":"Astrex.DeepSky.html"},{"type":"function","title":"Astrex.DeepSky.find_object/3","doc":"finds the specified object basing on the catalog and the id\ncatalog can be :messier, :ngc or :ic\n\nreturns a map for the object or empty map if the requested object\nis below the minimum altitude.\n\nif the minimum altitude is not specified, it is defaulted to 0°\ni.e. above the horizon","ref":"Astrex.DeepSky.html#find_object/3"},{"type":"function","title":"Examples - Astrex.DeepSky.find_object/3","doc":"iex> Astrex.Server.start_link\n\n    iex> Astrex.DeepSky.find_object(:messier, 1)\n    %{ar: \"05:34:31.97\",\n      constellation: \"Tau\",\n      decl: \"+22:00:52.1\",\n      id: \"NGC1952\",\n      kind: \"SNR\",\n      magnitude: \"\",\n      messier: \"1\"\n    }\n\n    iex> Astrex.DeepSky.find_object(:ngc, 1952)\n    %{\n      ar: \"05:34:31.97\",\n      constellation: \"Tau\",\n      decl: \"+22:00:52.1\",\n      id: \"NGC1952\",\n      kind: \"SNR\",\n      magnitude: \"\",\n      messier: \"1\"\n    }\n\n  NGC 6554 is more than 15° below the horizon\n  (on testing fake datetime and location)\n\n    iex> Astrex.DeepSky.find_object(:ngc, 6554, -15)\n    %{}\n\n  but it is found with searches down to -25° below the horizon\n  (on testing fake datetime and location)\n\n    iex> Astrex.DeepSky.find_object(:ngc, 6554, -25)\n    %{\n      ar: \"18:09:23.98\",\n      constellation: \"Sgr\",\n      decl: \"-18:22:43.3\",\n      id: \"NGC6554\",\n      kind: \"OCl\",\n      magnitude: \"\",\n      messier: \"\"\n    }","ref":"Astrex.DeepSky.html#find_object/3-examples"},{"type":"function","title":"Astrex.DeepSky.select_objects/2","doc":"","ref":"Astrex.DeepSky.html#select_objects/2"},{"type":"function","title":"Astrex.DeepSky.select_objects/3","doc":"","ref":"Astrex.DeepSky.html#select_objects/3"},{"type":"function","title":"Astrex.DeepSky.select_objects/4","doc":"finds all objects that meet the specifications:\n- maximum magnitude (anything as bright or brigther matches)\n- type of object (galaxies, open_clusters, globular_clusters, nebulas)\n- only from messier catalog pass the filter\n- not lower on the horizon than minimum_altitude degrees. Defaults to zero.\n  Negative altitudes are accepted to allow search for objects below the horizons.\n\naccepts up to 4 arguments:\n- magnitude         - required, integer\n- type              - required, atom\n- mes_only          - optional, boolean. When not specified defaults to false\n- minimum_altitude  - optional, integer. When not specified defaults to zero\nreturns a list of objects","ref":"Astrex.DeepSky.html#select_objects/4"},{"type":"function","title":"Examples - Astrex.DeepSky.select_objects/4","doc":"iex> Astrex.Server.start_link\n    iex> Astrex.DeepSky.select_objects(10, :nebulas, true, 25)\n    [\n      [\"NGC6720\", \"PN\", \"18:53:35.01\", \"+33:01:42.9\", \"Lyr\", \"9.70\", \"57\"],\n      [\"NGC6853\", \"PN\", \"19:59:36.38\", \"+22:43:15.7\", \"Vul\", \"7.60\", \"27\"]\n    ]\n\n  Two Messier nebulas found 25°+ above the horizon at the mock time/mock location\n\n    iex> Astrex.Server.start_link\n    iex> Astrex.DeepSky.select_objects(10, :nebulas, 25)\n    [\n      [\"IC0405\", \"Neb\", \"05:16:29.48\", \"+34:21:22.2\", \"Aur\", \"10.00\", \"\"],\n      [\"IC1805\", \"Cl+N\", \"02:32:41.51\", \"+61:27:24.8\", \"Cas\", \"7.03\", \"\"],\n      [\"IC1848\", \"Cl+N\", \"02:51:10.59\", \"+60:24:08.9\", \"Cas\", \"6.87\", \"\"],\n      [\"IC5070\", \"HII\", \"20:51:00.72\", \"+44:24:05.4\", \"Cyg\", \"8.00\", \"\"],\n      [\"IC5146\", \"Cl+N\", \"21:53:28.76\", \"+47:16:00.9\", \"Cyg\", \"7.82\", \"\"],\n      [\"NGC0246\", \"PN\", \"00:47:03.36\", \"-11:52:19.0\", \"Cet\", \"8.00\", \"\"],\n      [\"NGC1499\", \"Neb\", \"04:03:14.42\", \"+36:22:02.9\", \"Per\", \"5.00\", \"\"],\n      [\"NGC1555\", \"RfN\", \"04:21:59.43\", \"+19:32:06.6\", \"Tau\", \"9.98\", \"\"],\n      [\"NGC6543\", \"PN\", \"17:58:33.39\", \"+66:37:59.5\", \"Dra\", \"9.79\", \"\"],\n      [\"NGC6720\", \"PN\", \"18:53:35.01\", \"+33:01:42.9\", \"Lyr\", \"9.70\", \"57\"],\n      [\"NGC6823\", \"Cl+N\", \"19:43:09.89\", \"+23:17:59.8\", \"Vul\", \"7.71\", \"\"],\n      [\"NGC6853\", \"PN\", \"19:59:36.38\", \"+22:43:15.7\", \"Vul\", \"7.60\", \"27\"],\n      [\"NGC6888\", \"HII\", \"20:12:06.55\", \"+38:21:17.8\", \"Cyg\", \"7.44\", \"\"],\n      [\"NGC6960\", \"SNR\", \"20:45:58.18\", \"+30:35:42.5\", \"Cyg\", \"7.00\", \"\"],\n      [\"NGC6992\", \"SNR\", \"20:56:19.07\", \"+31:44:33.9\", \"Cyg\", \"7.00\", \"\"],\n      [\"NGC6995\", \"SNR\", \"20:57:10.76\", \"+31:14:06.6\", \"Cyg\", \"7.00\", \"\"],\n      [\"NGC7000\", \"HII\", \"20:59:17.14\", \"+44:31:43.6\", \"Cyg\", \"4.00\", \"\"],\n      [\"NGC7023\", \"Neb\", \"21:01:35.62\", \"+68:10:10.4\", \"Cep\", \"7.20\", \"\"],\n      [\"NGC7380\", \"Cl+N\", \"22:47:21.01\", \"+58:07:56.7\", \"Cep\", \"7.62\", \"\"],\n      [\"NGC7662\", \"PN\", \"23:25:53.90\", \"+42:32:05.8\", \"And\", \"9.20\", \"\"]\n    ]\n\n  The same selection returns 20 objects if the Messier requirement is not specified","ref":"Astrex.DeepSky.html#select_objects/4-examples"},{"type":"module","title":"Astrex.Server","doc":"Provides a GenServer to hold the local coordinates. This is useful for\n  applications that are localized (e.g. telescope control) and makes possible\n  to access the functions via the Astrex module, without supplying the local\n  coordinates each time.\n\n  Use of the GenServer is by no means mandatory. All the functions can be accessed\n  via the Astrex.Astro.* modules.\n\n  If the GenServer is used it is responsibility of the application to start, initialize\n  and supervise it","ref":"Astrex.Server.html"},{"type":"function","title":"Astrex.Server.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Astrex.Server.html#child_spec/1"},{"type":"function","title":"Astrex.Server.get_ll/0","doc":"","ref":"Astrex.Server.html#get_ll/0"},{"type":"function","title":"Astrex.Server.init/1","doc":"Callback implementation for  GenServer.init/1 .","ref":"Astrex.Server.html#init/1"},{"type":"function","title":"Astrex.Server.set_ll/1","doc":"","ref":"Astrex.Server.html#set_ll/1"},{"type":"function","title":"Astrex.Server.start_link/2","doc":"The Genserver is initialized using Greenwich coordinates, unless local coordinates are specified","ref":"Astrex.Server.html#start_link/2"},{"type":"function","title":"Astrex.Server.stop/0","doc":"","ref":"Astrex.Server.html#stop/0"},{"type":"module","title":"Astrex.Stars","doc":"This module provides functions to query for Bright stars in a list of 200 up to magnitude 3.1\n\n  The intended usage is retrieving the most appropriate stars to perform a 2/3 stars alignment of a telescope\n\n  The catalog is excerpted from https://in-the-sky.org/data/catalogue.php?cat=Bright+Star and\n  limited to one or two stars from each constellation, within the magnitude limits described above\n\n  The available columns are\n    0: Magnitude\n    1: Constellation\n    2: RA               Right Ascension - format hh:mm:ss\n    3: Dec              Declination     - format (-)deg:min:secs\n    4: Name             Primary name, such as α-CMa\n    5: aka              Also known as, such as Sirius\n\n  The following filtering are provided\n  - by magnitude (brighter than)\n  - by azimuth from a given position - not closer than specified degrees\n  - by azimuth from a given position - not farther than specified degrees\n  - by altitude from a given position - not closer than specified degrees\n  - by altitude from a given position - not farther than specified degrees\n\n  The filters can be combined\n\n  Note: Coordinates of the objects are returned in (+/-)dd:mm:ss and hh:mm:ss (strings)","ref":"Astrex.Stars.html"},{"type":"function","title":"Astrex.Stars.filter_name/2","doc":"","ref":"Astrex.Stars.html#filter_name/2"},{"type":"function","title":"Astrex.Stars.select_star_by_name/1","doc":"","ref":"Astrex.Stars.html#select_star_by_name/1"},{"type":"function","title":"Astrex.Stars.select_stars/1","doc":"","ref":"Astrex.Stars.html#select_stars/1"},{"type":"function","title":"Astrex.Stars.select_stars/2","doc":"","ref":"Astrex.Stars.html#select_stars/2"},{"type":"function","title":"Astrex.Stars.select_stars/3","doc":"finds all bright stars that meet the specifications:\n- maximum magnitude (anything as bright or brigther matches)\n- closer than X degrees from given coordinates (only close stars match)\n- farther than X degrees from given coordinates (only farther stars match)\n\naccepts 3 arguments:\n- magnitude         - required, integer\n\n- %{az: ref_az, d_az: delta_az, type_az: \"IN\"/\"OUT\"} - optional, map\n                    delta_az is the distance plus/minus ref_az defining the search interval\n                    type_az, IN/OUT, determines the search IN or OUT the interval\n\n- %{alt: ref_alt, d_alt: delta_alt, type_alt: \"IN\"/\"OUT\"} - optional, map\n                    delta_az is the distance plus/minus ref_az defining the search interval\n                    type_az, IN/OUT, determines the search IN or OUT the interval","ref":"Astrex.Stars.html#select_stars/3"},{"type":"function","title":"Examples - Astrex.Stars.select_stars/3","doc":"iex> Astrex.Server.start_link\n    iex> Astrex.Stars.select_stars(0.5, %{az: 90, d_az: 45, type_az: \"IN\"}, %{alt: 60, d_alt: 30, type_alt: \"IN\"})\n    [\n      %{aka: \"Capella\", alt: 46.471899486382085, ra: \"05:16:41\", az: 69.23413116540189, const: \"Auriga\", dec: \"45:59:56\", id: \"α-Aur\", mag: \"0.1\"}\n    ]\n\n    one star found matching the requirements at the mock time/mock location\n\n          Astrex.Server.get_ll --> %{lat: 51.477928, long: 0.0}\n          Astrex.Common.ndt_now --> ~N[2023-01-01 18:00:15.922068]\n\n    iex> Astrex.Server.start_link\n    iex> Astrex.Stars.select_stars(0.5)\n    [\n      %{aka: \"Capella\", alt: 46.471899486382085, az: 69.23413116540189, const: \"Auriga\", dec: \"45:59:56\", id: \"α-Aur\", mag: \"0.1\", ra: \"05:16:41\"},\n      %{aka: \"Vega\", alt: 28.25618477533259, az: 297.8147144352378, const: \"Lyra\", dec: \"38:46:58\", id: \"α-Lyr\", mag: \"0.0\", ra: \"18:36:56\"},\n      %{aka: \"Rigel\", alt: 7.176735179533099, az: 112.89401627493982, const: \"Orion\", dec: \"-08:12:05\", id: \"β-Ori\", mag: \"0.3\", ra: \"05:14:32\"},\n      %{aka: \"Procyon\", alt: -4.292759056473423, az: 76.05487291217511, const: \"Canis Minor\", dec: \"05:13:39\", id: \"α-CMi\", mag: \"0.4\", ra: \"07:39:18\"},\n      %{aka: \"Sirius\", alt: -13.057787690330622, az: 100.52410739917546, const: \"Canis Major\", dec: \"-16:42:47\", id: \"α-CMa\", mag: \"-1.4\", ra: \"06:45:09\"},\n      %{aka: \"Arcturus\", alt: -16.585528504402962, az: 337.6290585758656, const: \"Bootes\", dec: \"19:11:14\", id: \"α-Boo\", mag: \"0.2\", ra: \"14:15:40\"},\n      %{aka: \"Achernar\", alt: -19.256179758399565, az: 172.46262860557806, const: \"Eridanus\", dec: \"-57:14:11\", id: \"α-Eri\", mag: \"0.5\", ra: \"01:37:42\"},\n      %{aka: \"Canopus\", alt: -36.018291932764726, az: 131.73791696086482, const: \"Carina\", dec: \"-52:41:44\", id: \"α-Car\", mag: \"-0.6\", ra: \"06:23:57\"},\n      %{aka: \"Rigil Kentaurus\", alt: -71.68742064459886, az: 228.18421733259387, const: \"Centaurus\", dec: \"-60:50:06\", id: \"α-Cen\", mag: \"-0.0\", ra: \"14:39:40\"},\n    ]\n\n    all 9 stars brigther than magnitude 0.5 matched the specification and where returned in order of altitude (highest first)","ref":"Astrex.Stars.html#select_stars/3-examples"},{"type":"module","title":"Astrex.Types","doc":"","ref":"Astrex.Types.html"},{"type":"type","title":"Astrex.Types.altazimuth/0","doc":"","ref":"Astrex.Types.html#t:altazimuth/0"},{"type":"type","title":"Astrex.Types.ecliptical/0","doc":"","ref":"Astrex.Types.html#t:ecliptical/0"},{"type":"type","title":"Astrex.Types.equatorial/0","doc":"","ref":"Astrex.Types.html#t:equatorial/0"},{"type":"type","title":"Astrex.Types.latlong/0","doc":"","ref":"Astrex.Types.html#t:latlong/0"},{"type":"type","title":"Astrex.Types.solar_system/0","doc":"","ref":"Astrex.Types.html#t:solar_system/0"},{"type":"extras","title":"Astrex","doc":"# Astrex\n\n**Astrex is an astronomy library written in Elixir**\n\nprovides functions to perfom typical astronomy calculations such as:\n- coordinates conversion between equatorial and horizontal coordinates\n- calculates the position of solar system objects (Moon and planets)\n- calculates the magnetic declination to enable finding the \"true north\"\n- includes a full blown NGC and IC objects database with query functionalities","ref":"readme.html"},{"type":"extras","title":"History - Astrex","doc":"- version 0.3.4 - first public release\n- version 0.4.0 - update WMM.COF to 2025 release - added 200 brightest stars catalogue","ref":"readme.html#history"},{"type":"extras","title":"Installation - Astrex","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `astrex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:astrex, \"~> 0.4.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}